import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'dart:math';
import 'favorite_page.dart';
import 'app_state.dart';

void main() => runApp(const TindBook());

class TindBook extends StatelessWidget {
  const TindBook({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => TindBookState(),
      child: MaterialApp(
        theme: ThemeData(
          primarySwatch: Colors.blue,
          primaryColor: Color.fromRGBO(204, 213, 174, 1),
          backgroundColor: Color.fromRGBO(233, 237, 201, 1),
          scaffoldBackgroundColor: Color.fromRGBO(254, 250, 224, 1),
          appBarTheme: AppBarTheme(
            backgroundColor: Color.fromRGBO(204, 213, 174, 1), // Set app bar color
          ),
          navigationRailTheme: NavigationRailThemeData(
            backgroundColor: Color.fromRGBO(212, 163, 115, 1), // Set navigation rail color
          ),
        ),
        title: 'Tind Book',
        home: Scaffold(
          appBar: AppBar(title: const Text('Draggable Sample')),
          body: const MyHomePage(),
        ),
      ),
    );
  }
}

class TindBookState extends ChangeNotifier {
  // List of image paths
  List<String> imagePaths = [
    'assets/images/passeur.png',
    'assets/images/1.jpg',
    'assets/images/2.jpg',
    // Add more image paths as needed
  ];

  // Index of the currently displayed image
  int currentImageIndex = 0;

  // Function to handle swiping in any direction
  void handleSwipe(int direction) {
    if (direction == 1) {
      // Swipe right
      if (currentImageIndex < imagePaths.length - 1) {
        currentImageIndex++;
        notifyListeners();
      }
    } else {
      // Swipe left
      if (currentImageIndex > 0) {
        currentImageIndex--;
        notifyListeners();
      }
    }
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key}) : super(key: key);

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  var selectedIndex = 0;

  @override
  Widget build(BuildContext context) {
    Widget page;
    switch (selectedIndex) {
      case 0:
        page = TindBookContent();
        break;
      case 1:
        page = FavoritePage();
        break;
      case 2:
        page = Placeholder();
        break;
      default:
        throw UnimplementedError('no widget for $selectedIndex');
    }

    return LayoutBuilder(
      builder: (context, constraints) {
        return Scaffold(
          body: Row(
            children: [
              SafeArea(
                child: NavigationRail(
                  extended: constraints.maxWidth >= 600,
                  destinations: [
                    NavigationRailDestination(
                      icon: Icon(Icons.home),
                      label: Text('Home'),
                    ),
                    NavigationRailDestination(
                      icon: Icon(Icons.swipe),
                      label: Text('Swipe'),
                    ),
                    NavigationRailDestination(
                      icon: Icon(Icons.info),
                      label: Text('About'),
                    ),
                  ],
                  selectedIndex: selectedIndex,
                  onDestinationSelected: (value) {
                    print('selected: $value');
                    setState(() {
                      selectedIndex = value;
                    });
                  },
                ),
              ),
              VerticalDivider(
                thickness: 1,
                width: 1,
              ), // Add a vertical divider
              Expanded(
                child: Container(
                  color: Color.fromRGBO(250, 237, 205, 1),
                  child: page,
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}

class TindBookContent extends StatefulWidget {
  const TindBookContent({Key? key}) : super(key: key);

  @override
  State<TindBookContent> createState() => _TindBookContentState();
}

class _TindBookContentState extends State<TindBookContent> {
  late TindBookState state;
  double _startX = 0.0;
  double _currentX = 0.0;
  double _deltaX = 0.0;
  bool _isSwiping = false;

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    state = Provider.of<TindBookState>(context);
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (context, constraints) {
        double containerWidth = constraints.maxWidth;
        double containerHeight = constraints.maxHeight;

        return GestureDetector(
          onHorizontalDragStart: (details) {
            _startX = details.globalPosition.dx;
            _isSwiping = true;
          },
          onHorizontalDragUpdate: (details) {
            if (_isSwiping) {
              _currentX = details.globalPosition.dx;
              _deltaX = _currentX - _startX;
              setState(() {});
            }
          },
          onHorizontalDragEnd: (details) {
            if (_isSwiping) {
              _isSwiping = false;
              if (_deltaX > 50) {
                // Swipe right
                state.handleSwipe(1);
              } else if (_deltaX < -50) {
                // Swipe left
                state.handleSwipe(-1);
              }
            }
            _startX = 0.0;
            _currentX = 0.0;
            _deltaX = 0.0;
          },
          child: Stack(
            children: [
              Positioned.fill(
                child: Container(
                  color: Color.fromRGBO(250, 237, 205, 1),
                  height: containerHeight / 3,
                  width: containerWidth / 3,
                ),
              ),
              Positioned(
                top: 0,
                left: 0,
                right: 0,
                bottom: 0,
                child: Transform.translate(
                  offset: Offset(_deltaX, 0.0),
                  child: Transform.rotate(
                    angle: _deltaX * 0.0002, // Adjust the rotation speed here
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(100), // Adjust the radius as needed
                      child: Image.asset(
                        state.imagePaths[state.currentImageIndex],
                        height: containerHeight / 3, // Adjust image height
                        width: containerWidth / 3, // Adjust image width
                        fit: BoxFit.contain,
                      ),
                    ),
                  ),
                ),
              ),
              Positioned(
                top: 20,
                left: 20,
                right: 20,
                child: Container(
                  padding: EdgeInsets.all(10),
                  decoration: BoxDecoration(
                    color: Colors.black.withOpacity(0.5),
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        'Titre du livre ',
                        style: TextStyle(
                          color: Colors.white,
                          fontSize: 20,
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                      SizedBox(height: 5),
                      Text(
                        'un tres bon livre qui parle de beaucoup chose , notamment mais aussi de lorem ipsum dolor sit amet a m Doctrine est pas de ',
                        style: TextStyle(
                          color: Colors.white,
                          fontSize: 16,
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}

class FavoritePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: [
          Text('Test'),
        ],
      ),
    );
  }
}
